scxpand.pretrained.download\_manager
====================================

.. automodule:: scxpand.pretrained.download_manager

   
   .. rubric:: Functions

   .. autosummary::
   
      download_model
      download_pretrained_model
   